#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef GETTEXT_PACKAGE
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef PACKAGE
#undef VERSION
#undef HAVE_LIBSM
#undef GETTEXT_PACKAGE
#undef WE_ARE_LIBGNOMEPRINT_INTERNALS
#undef GPA_MODULES_DIR
#undef GNOME_PRINT_MODULES_DIR
#undef GNOME_PRINT_DATA_DIR
